@@ -13,8 +13,10 @@
 #include <math.h>
 #include <limits.h>
 
+#ifndef _MSC_VER
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
+#endif
 
 /*-------------------------------------------------------------------------*/
 /* Local includes							   */
@@ -444,8 +446,13 @@ XPoint UGetCursor()
    /* Don't use areawin->window;  if called from inside an object	*/
    /* (e.g., "here" in a Tcl expression), areawin->window will be	*/
    /* an off-screen pixmap, and cause a crash.				*/
+#ifndef _MSC_VER
    XQueryPointer(dpy, Tk_WindowId(areawin->area), &nullwin, &nullwin,
 	&nullint, &nullint, &xpos, &ypos, &nullui);
+#else
+   XQueryPointer_TkW32(dpy, Tk_WindowId(areawin->area), &nullwin, &nullwin,
+	&nullint, &nullint, &xpos, &ypos, &nullui);
+#endif
 #else
    XQueryPointer(dpy, areawin->window, &nullwin, &nullwin, &nullint,
 	&nullint, &xpos, &ypos, &nullui);
