@@ -196,7 +196,7 @@ extern void movepoints(genericptr *, short, short);
 #ifndef TCL_WRAPPER
 extern void xlib_makeobject(xcWidget, caddr_t);
 #endif
-extern void domakeobject(int);
+extern objinstptr domakeobject(int, char *, Boolean);
 extern void selectsave(xcWidget, caddr_t, caddr_t);
 extern void arceditpush(arcptr);
 extern void splineeditpush(splineptr);
