@@ -45,6 +45,7 @@ extern Display	*dpy;
 extern int *appcolors;
 extern Cursor	appcursors[NUM_CURSORS];
 extern XCWindowData *areawin;
+extern Globaldata xobjs;
 extern char _STR[150];
 extern short textpos, textend;
 
@@ -845,7 +846,8 @@ void unselect_all()
    clearselects();
 
 #ifdef TCL_WRAPPER
-   Tcl_Eval(xcinterp, "xcircuit::updateparams");
+   if (xobjs.suspend < 0)
+      Tcl_Eval(xcinterp, "xcircuit::updateparams");
 #endif
 
 }
@@ -1189,7 +1191,8 @@ short *recurse_select_element(short class, u_char mode) {
    saveselect = rselect;
 
 #ifdef TCL_WRAPPER
-   Tcl_Eval(xcinterp, "xcircuit::updateparams");
+   if (xobjs.suspend < 0)
+      Tcl_Eval(xcinterp, "xcircuit::updateparams");
 #endif
 
    return areawin->selectlist;
